function [OutCellArray, Outconfig]=FreqMapIFFT(InCellArray, Inconfig)
% MapIFFT takes the inverse fourier transform of a 2D frequency map.
%
% The inverse FFT is computed as:
%
% IFFT =  xSize * ySize * real(ifft2) /4 /deltaX /deltaY /maxFreqX /maxFreqY
%
% where "ifft2" is the MATLAB command of the same name. "deltaX" and
% "deltaY" are the pixel spacing and are used to account for the unit
% scaling when approximating an integration by summation. "xSize" and
% "ySize" are the input map sizes. They represent a normalization factor
% which keeps the output units simple. "maxFreqX" and "maxFreqY" represent
% the maximum frequencies in the data.
%
% NOTE: The ifft2 function used in this rountine makes use of a fast
% fourier transform with a scaling factor of 1/xSize/ySize. Different
% programs and algorithms may use different scaling factors for their
% transforms and inverse transforms. These scale factors are consistent
% with MapFFT and cimplify the output units.
%
% Inputs: Frequency Map
% Outputs: Map
%
% Author: Ping Zhou
% Email:
%
% Version history:
% 9/9/10 - Version 1
% 6/21/12 - Version 3 - G. Smith - normalized output to keep units simple
% 10/10/12 - Version 3.1 - G. Smith - added detailed information to help 

OutCellArray{1}=InCellArray{1};
OutCellArray{1}.type='map';

% get frequency information
x_max_freq=str2double(InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'X Max Frequency'),2});
y_max_freq=str2double(InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Y Max Frequency'),2});

% convert units
xunit=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'X Unit'),2};
xunit=strrep(xunit, '1/', '');
yunit=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Y Unit'),2};
yunit=strrep(yunit, '1/', '');
zunit=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Z Unit'),2};

% compute basic quantities
x_pts = size(InCellArray{1}.data, 2);
y_pts = size(InCellArray{1}.data, 1);
x_size=x_pts/(2*x_max_freq);
y_size=y_pts/(2*y_max_freq);
delx = x_size/x_pts;
dely = y_size/y_pts;

% build up output header
OutCellArray{1}.header = [];
OutCellArray{1}.header={'Date Created', ''};
OutCellArray{1}.header(end+1, :)={'X Size', num2str(x_size)};
OutCellArray{1}.header(end+1, :)={'Y Size', num2str(y_size)};
OutCellArray{1}.header(end+1,:)={'X unit', xunit};
OutCellArray{1}.header(end+1,:)={'Y unit', yunit};
OutCellArray{1}.header(end+1,:)={'Z unit', zunit};

Outconfig=Inconfig;

% compute inverse transform and scale
data = InCellArray{1}.data;
data(isnan(data))=0;

G=ifft2(ifftshift(data))/delx/dely;

% G.S. - 2012/06/21 - divide by area of freqmap to keep output units simple
OutCellArray{1}.data=real(G)/4/x_max_freq/y_max_freq*size(data,1)*size(data,2);
end